==> spirit_hub-0.0.1.3.tar.gz: spirit_hub-0.0.1.3/app/assets/javascripts/spirit_hub/controllers/docviewer_controller.js <==
import { Controller } from '@hotwired/stimulus';
import debounce from 'debounce';

export default class extends Controller {
  static targets = [
    'page',
    'navigationPage',
    'indexIndicator',
    'zoomIndicator',
    'nextPageButton',
    'previousPageButton',
    'zoomInButton',
    'zoomOutButton',
    'scrollArea',
    'selectedPageContainer',
  ];

  static values = {
    index: { type: Number, default: 0 },
    zoom: { type: Number, default: 1 },
  };

  static classes = ['navigationActive'];

  connect() {
    super.connect();
    this.blockScrollUpdate = false;

    this.currentPageSize = this.calculatePagesSizes();
    // If any page has width or height of 0, it means that the image is not loaded yet.
    if (this.currentPageSize.some(page => page.width === 0 || page.height === 0)) {
      this.currentPageSize = null;
      Promise.all([...this.pageTargets].map(im => new Promise(resolve => (im.onload = resolve)))).then(() => {
        this.currentPageSize = this.calculatePagesSizes();
      });
    }

    this.onScroll = debounce(this.onScroll.bind(this), 30);
  }

  calculatePagesSizes() {
    return Array.from(this.pageTargets).map(img => {
      return {
        width: img.width,
        height: img.height,
        top: img.offsetTop,
        bottom: img.offsetTop + img.height,
      };
    });
  }

  onScroll() {
    if (!this.blockScrollUpdate && this.currentPageSize) {
      const scrollAreaMiddle = this.scrollAreaTarget.scrollTop + 16 + this.scrollAreaTarget.clientHeight / 2;
      this.currentPageSize.forEach((size, idx) => {
        if (scrollAreaMiddle >= size.top && scrollAreaMiddle < size.bottom) {
          this.indexValue = idx;
        }
      });
    }
    this.blockScrollUpdate = false;
  }

  atMinIndex() {
    return this.indexValue <= 0;
  }

  atMaxIndex() {
    return this.indexValue >= this.pageTargets.length - 1;
  }

  nextPage() {
    if (!this.atMaxIndex()) {
      this.indexValue++;
      this.scrollToCurrentIndex();
    }
  }

  previousPage() {
    if (!this.atMinIndex()) {
      this.indexValue--;
      this.scrollToCurrentIndex();
    }
  }

  goToPage(event) {
    const dataPage = event.target.getAttribute('data-page');
    this.indexValue = parseInt(dataPage);
    this.scrollToCurrentIndex();
  }

  scrollToCurrentIndex() {
    const targetElement = this.pageTargets[this.indexValue];
    const container = this.scrollAreaTarget;
    const containerOffsetTop = container.getBoundingClientRect().top;
    const targetOffsetTop = targetElement.getBoundingClientRect().top;
    const scrollPosition = container.scrollTop + (targetOffsetTop - containerOffsetTop);

    container.scrollTo({
      top: scrollPosition,
      behavior: 'auto',
    });

    this.blockScrollUpdate = true;
  }

  indexValueChanged() {
    this.indexIndicatorTarget.value = this.indexValue + 1;
    this.disableButtonIfNeeded(this.nextPageButtonTarget, this.atMaxIndex());
    this.disableButtonIfNeeded(this.previousPageButtonTarget, this.atMinIndex());

    if (this.selectedPage) {
      this.selectedPage.classList.remove(this.navigationActiveClass);
    }
    this.selectedPage = this.navigationPageTargets[this.indexValue];
    this.selectedPage.classList.add(this.navigationActiveClass);

    this.scrollToSelectedPageIfNeeded();
  }

  scrollToSelectedPageIfNeeded() {
    const container = this.selectedPageContainerTarget;
    const pageElement = this.selectedPage;
    const containerTop = container.scrollTop;
    const containerOffsetTop = container.getBoundingClientRect().top;
    const pageOffsetTop = pageElement.getBoundingClientRect().top;
    const scrollPosition = containerTop + (pageOffsetTop - containerOffsetTop);

    container.scrollTo({
      top: scrollPosition,
      behavior: 'auto',
    });
  }

  atMaxZoom() {
    return this.zoomValue >= 2.5;
  }

  atMinZoom() {
    return this.zoomValue <= 0.5;
  }

  zoomIn() {
    if (!this.atMaxZoom()) {
      this.zoomValue += 0.1;
    }
  }

  zoomOut() {
    if (!this.atMinZoom()) {
      this.zoomValue -= 0.1;
    }
  }

  zoomValueChanged(newZoom, oldZoom) {
    this.zoomValue = Number(newZoom.toFixed(1));

    if (!this.currentPageSize) {
      return;
    }

    this.pageTargets.forEach((img, idx) => {
      img.style.width = this.calculatePageStyleSize(this.currentPageSize[idx].width, newZoom, oldZoom);
      img.style.height = this.calculatePageStyleSize(this.currentPageSize[idx].height, newZoom, oldZoom);
    });

    this.currentPageSize = this.calculatePagesSizes();

    this.zoomIndicatorTarget.textContent = Math.floor(newZoom * 100);
    this.disableButtonIfNeeded(this.zoomInButtonTarget, this.atMaxZoom());
    this.disableButtonIfNeeded(this.zoomOutButtonTarget, this.atMinZoom());

    this.scrollToCurrentIndex();
  }

  calculatePageStyleSize(currentValue, scale, oldScale) {
    return `${Number(currentValue * (scale / oldScale)).toFixed(0)}px`;
  }

  disableButtonIfNeeded(btn, condition) {
    condition ? btn.setAttribute('disabled', '') : btn.removeAttribute('disabled');
  }

  indexIndicatorKeyDown(event) {
    if (event.key === 'Enter') {
      let pageNumber = this.indexIndicatorTarget.value - 1;
      this.indexValue = parseInt(pageNumber);
      this.scrollToCurrentIndex();
    }
  }
}

==> spirit_hub-0.1.1.6.tar.gz: spirit_hub-0.1.1.6/app/assets/javascripts/spirit_hub/controllers/docviewer_controller.js <==
import { Controller } from '@hotwired/stimulus';
import debounce from 'debounce';

export default class extends Controller {
  static targets = [
    'page',
    'navigationPage',
    'indexIndicator',
    'zoomIndicator',
    'nextPageButton',
    'previousPageButton',
    'zoomInButton',
    'zoomOutButton',
    'scrollArea',
    'selectedPageContainer',
  ];

  static values = {
    index: { type: Number, default: 0 },
    zoom: { type: Number, default: 1 },
  };

  static classes = ['navigationActive'];

  connect() {
    super.connect();
    this.blockScrollUpdate = false;

    this.currentPageSize = this.calculatePagesSizes();
    // If any page has width or height of 0, it means that the image is not loaded yet.
    if (this.currentPageSize.some(page => page.width === 0 || page.height === 0)) {
      this.currentPageSize = null;
      Promise.all([...this.pageTargets].map(im => new Promise(resolve => (im.onload = resolve)))).then(() => {
        this.currentPageSize = this.calculatePagesSizes();
      });
    }

    this.onScroll = debounce(this.onScroll.bind(this), 30);
  }

  calculatePagesSizes() {
    return Array.from(this.pageTargets).map(img => {
      return {
        width: img.width,
        height: img.height,
        top: img.offsetTop,
        bottom: img.offsetTop + img.height,
      };
    });
  }

  onScroll() {
    if (!this.blockScrollUpdate && this.currentPageSize) {
      const scrollAreaMiddle = this.scrollAreaTarget.scrollTop + 16 + this.scrollAreaTarget.clientHeight / 2;
      this.currentPageSize.forEach((size, idx) => {
        if (scrollAreaMiddle >= size.top && scrollAreaMiddle < size.bottom) {
          this.indexValue = idx;
        }
      });
    }
    this.blockScrollUpdate = false;
  }

  atMinIndex() {
    return this.indexValue <= 0;
  }

  atMaxIndex() {
    return this.indexValue >= this.pageTargets.length - 1;
  }

  nextPage() {
    if (!this.atMaxIndex()) {
      this.indexValue++;
      this.scrollToCurrentIndex();
    }
  }

  previousPage() {
    if (!this.atMinIndex()) {
      this.indexValue--;
      this.scrollToCurrentIndex();
    }
  }

  goToPage(event) {
    const dataPage = event.target.getAttribute('data-page');
    this.indexValue = parseInt(dataPage);
    this.scrollToCurrentIndex();
  }

  scrollToCurrentIndex() {
    const targetElement = this.pageTargets[this.indexValue];
    const container = this.scrollAreaTarget;
    const containerOffsetTop = container.getBoundingClientRect().top;
    const targetOffsetTop = targetElement.getBoundingClientRect().top;
    const scrollPosition = container.scrollTop + (targetOffsetTop - containerOffsetTop);

    container.scrollTo({
      top: scrollPosition,
      behavior: 'auto',
    });

    this.blockScrollUpdate = true;
  }

  indexValueChanged() {
    this.indexIndicatorTarget.value = this.indexValue + 1;
    this.disableButtonIfNeeded(this.nextPageButtonTarget, this.atMaxIndex());
    this.disableButtonIfNeeded(this.previousPageButtonTarget, this.atMinIndex());

    if (this.selectedPage) {
      this.selectedPage.classList.remove(this.navigationActiveClass);
    }
    this.selectedPage = this.navigationPageTargets[this.indexValue];
    this.selectedPage.classList.add(this.navigationActiveClass);

    this.scrollToSelectedPageIfNeeded();
  }

  scrollToSelectedPageIfNeeded() {
    const container = this.selectedPageContainerTarget;
    const pageElement = this.selectedPage;
    const containerTop = container.scrollTop;
    const containerOffsetTop = container.getBoundingClientRect().top;
    const pageOffsetTop = pageElement.getBoundingClientRect().top;
    const scrollPosition = containerTop + (pageOffsetTop - containerOffsetTop);

    container.scrollTo({
      top: scrollPosition,
      behavior: 'auto',
    });
  }

  atMaxZoom() {
    return this.zoomValue >= 2.5;
  }

  atMinZoom() {
    return this.zoomValue <= 0.5;
  }

  zoomIn() {
    if (!this.atMaxZoom()) {
      this.zoomValue += 0.1;
    }
  }

  zoomOut() {
    if (!this.atMinZoom()) {
      this.zoomValue -= 0.1;
    }
  }

  zoomValueChanged(newZoom, oldZoom) {
    this.zoomValue = Number(newZoom.toFixed(1));

    if (!this.currentPageSize) {
      return;
    }

    this.pageTargets.forEach((img, idx) => {
      img.style.width = this.calculatePageStyleSize(this.currentPageSize[idx].width, newZoom, oldZoom);
      img.style.height = this.calculatePageStyleSize(this.currentPageSize[idx].height, newZoom, oldZoom);
    });

    this.currentPageSize = this.calculatePagesSizes();

    this.zoomIndicatorTarget.textContent = Math.floor(this.zoomValue * 100);
    this.disableButtonIfNeeded(this.zoomInButtonTarget, this.atMaxZoom());
    this.disableButtonIfNeeded(this.zoomOutButtonTarget, this.atMinZoom());

    this.scrollToCurrentIndex();
  }

  calculatePageStyleSize(currentValue, scale, oldScale) {
    return `${Number(currentValue * (scale / oldScale)).toFixed(0)}px`;
  }

  disableButtonIfNeeded(btn, condition) {
    condition ? btn.setAttribute('disabled', '') : btn.removeAttribute('disabled');
  }

  indexIndicatorKeyDown(event) {
    if (event.key === 'Enter') {
      let pageNumber = this.indexIndicatorTarget.value - 1;
      this.indexValue = parseInt(pageNumber);
      this.scrollToCurrentIndex();
    }
  }
}
